<?php

namespace Drupal\secure_nodes;

use Drupal\Core\Database\Connection;
use Drupal\node\Entity\Node;

/**
 * Contains the Protected Nodes Enabler service.
 */
class EnablerService {

  /**
   * The database connection used to check the IP against.
   *
   * @var \Drupal\Core\Database\Connection
   */
  protected $dbConnection;

  /**
   * Constructs a database connection object.
   *
   * @param \Drupal\Core\Database\Connection $connection
   *   The database connection which will be used connect the custom table.
   */
  public function __construct(Connection $connection) {
    $this->dbConnection = $connection;
  }

  /**
   * Checks if an individual node is Protected Nodes enabled.
   *
   * @param Drupal\node\Entity\Node $node
   *   The Node.
   *
   * @return bool
   *   whether or not the node is enabled for the Protected Nodes functionality.
   */
  public function isEnabled(Node &$node) {
    if ($node->isNew()) {
      return FALSE;
    }
    try {
      $select = $this->dbConnection->select('secure_nodes', 're');
      $select->fields('re', ['nid']);
      $select->condition('nid', $node->id());
      $results = $select->execute();

      return !(empty($results->fetchCol()));
    }
    catch (\Exception $e) {
      \Drupal::messenger()->addError(
        t('Unable to determine Protected Nodes settings at this time. Please try again.')
      );
      return NULL;
    }
  }

  /**
   * Get all results.
   *
   * @return array
   *   return all columns.
   */
  public function getAll() {

    $select = $this->dbConnection->select('secure_nodes', 'nodes');
    $select->fields('nodes', ['nid']);
    $results = $select->execute();
    return $results->fetchCol();

  }

  /**
   * Sets an individual node to be Protected Nodes enabled.
   *
   * @param Drupal\node\Entity\Node $node
   *   The node object.
   *
   * @throws Exception
   */
  public function setEnabled(Node $node) {
    try {
      if (!($this->isEnabled($node))) {
        $insert = $this->dbConnection->insert('secure_nodes');
        $insert->fields(['nid']);
        $insert->values([$node->id()]);
        $insert->execute();
      }
    }
    catch (\Exception $e) {
      \Drupal::messenger()->addError(
        t('Unable to save Protected Nodes settings at this time. Please try again.')
      );
    }
  }

  /**
   * Deletes PRotected Nodes enabled settings for an individual node.
   *
   * @param Drupal\node\Entity\Node $node
   *   The node object.
   */
  public function delEnabled(Node $node) {
    try {
      $delete = $this->dbConnection->delete('secure_nodes');
      $delete->condition('nid', $node->id());
      $delete->execute();
    }
    catch (\Exception $e) {
      \Drupal::messenger()->addError(
        t('Unable to save Protected Nodes settings at this time. Please try again.')
      );
    }
  }

}
